#################
PyCogent Cookbook
#################

Contents:

.. toctree::
    :maxdepth: 1
    
    introduction
    tips_for_using_python
    accessing_databases
    manipulating_biological_data
    analysis_of_sequence_composition
    sequence_similarity_search
    controlling_third_party_applications
    building_alignments
    building_phylogenies
    structural_data
    using_likelihood_to_perform_evolutionary_analyses
    sequence_simulation
    standard_statistical_analyses
    multivariate_data_analysis
    community_analysis
    dealing_with_hts_data
    hpc_environments
    useful_utilities
    code_development
